from setuptools import setup

setup(name='dsnd_distributions_rim119',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['distributions'],
      zip_safe=False)
